@@ -570,7 +570,7 @@ public Q_SLOTS:
 
     void setIsManaged(bool managed)
     {
-        if (m_isManaged = managed)
+        if (m_isManaged == managed)
         {
             return;
         }
